@@ -26,14 +26,14 @@
 #include <KDebug>
 #include <KMessageBox>
 #include <KIcon>
+#include <KInputDialog>
 
-#include <QtGui/QSpinBox>
-#include <QtGui/QCheckBox>
-#include <QtGui/QDoubleSpinBox>
-#include <QtGui/QLabel>
-#include <QtGui/QInputDialog>
-#include <QtGui/QGridLayout>
-#include <QtGui/QToolButton>
+#include <QSpinBox>
+#include <QCheckBox>
+#include <QDoubleSpinBox>
+#include <QLabel>
+#include <QGridLayout>
+#include <QToolButton>
 
 /*
 Profiles are saved in karboncalligraphyrc
@@ -214,11 +214,10 @@ void KarbonCalligraphyOptionWidget::saveProfileAs()
     // loop until a valid name is entered or the user cancelled
     while (1) {
         bool ok;
-        name = QInputDialog::getText(this,
-                                     i18n("Profile name"),
+        name = KInputDialog::getText(i18n("Profile name"),
                                      i18n("Please insert the name by which "
                                           "you want to save this profile:"),
-                                     QLineEdit::Normal, QString(), &ok);
+                                     QString(), &ok, this);
         if (! ok) return;
 
         if (name.isEmpty() || name == i18n("Current")) {
@@ -283,8 +282,8 @@ void KarbonCalligraphyOptionWidget::decreaseAngle()
 
 void KarbonCalligraphyOptionWidget::createConnections()
 {
-    connect(m_comboBox, SIGNAL(currentIndexChanged(const QString &)),
-            SLOT(loadProfile(const QString &)));
+    connect(m_comboBox, SIGNAL(currentIndexChanged(QString)),
+            SLOT(loadProfile(QString)));
 
 
     // propagate changes
