@@ -69,8 +69,11 @@ ImportTableWizard::ImportTableWizard ( KexiDB::Connection* curDB, QWidget* paren
     setupAlterTablePage();
     setupImportingPage();
     setupFinishPage();
+    setValid(m_srcConnPageItem, false);
     
     connect(this, SIGNAL(currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)), this, SLOT(slot_currentPageChanged(KPageWidgetItem*,KPageWidgetItem*)));
+    //! @todo Change this to message prompt when we move to non-dialog wizard.
+    connect(m_srcConnSel, SIGNAL(connectionSelected(bool)), this, SLOT(slotConnPageItemSelected(bool)));
 }
 
 
@@ -86,14 +89,20 @@ void ImportTableWizard::back() {
 }
 
 void ImportTableWizard::next() {
-    if (currentPage() == m_importingPageItem) {
+    if (currentPage() == m_srcConnPageItem) {
+      if (fileBasedSrcSelected()) {
+          setAppropriate(m_srcDBPageItem, false);
+      } else {  
+          setAppropriate(m_srcDBPageItem, true);
+      }
+    } else if (currentPage() == m_importingPageItem) {
         if (doImport()) {
             KAssistantDialog::next();
             return;
         }
     } else if (currentPage() == m_alterTablePageItem) {
       if (m_currentDatabase->objectNames().contains(m_alterSchemaWidget->newSchema()->name(),Qt::CaseInsensitive)) {
-            KMessageBox::information(this, i18n("An object with this name already exists, please change the table name to continue", i18n("Object name exists")));
+            KMessageBox::information(this, i18n("An object with this name already exists, please change the table name to continue.", i18n("Object Name Exists")));
             return;
       }
     }  
@@ -184,6 +193,8 @@ void ImportTableWizard::setupTableSelectPage() {
 
     m_tableListWidget = new QListWidget(this);
     m_tableListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
+    connect(m_tableListWidget, SIGNAL(itemSelectionChanged()),
+            this, SLOT(slotTableListWidgetSelectionChanged()));
     
     vbox->addWidget(m_tableListWidget);
     
@@ -317,17 +328,28 @@ void ImportTableWizard::arriveTableSelectPage()
 {
     Kexi::ObjectStatus result;
     KexiUtils::WaitCursor wait;
+    m_tableListWidget->clear();
     m_migrateDriver = prepareImport(result);
 
     if (m_migrateDriver) {
-        if (!m_migrateDriver->connectSource())
+        if (!m_migrateDriver->connectSource()) {
+            kDebug() << "unable to connect to database";
             return;
-
+        }
+        
         QStringList tableNames;
-        m_tableListWidget->clear();
         if (m_migrateDriver->tableNames(tableNames)) {
             m_tableListWidget->addItems(tableNames);
         }
+        if (m_tableListWidget->item(0)) {
+            m_tableListWidget->item(0)->setSelected(true);
+        }
+    } else {
+        kDebug() << "No driver for selected source";
+        QString errMessage =result.message.isEmpty() ? i18n("Unknown error") : result.message;
+        QString errDescription = result.description.isEmpty() ? errMessage : result.description;
+        KMessageBox::error(this, errMessage, errDescription);
+        setValid(m_tablesPageItem, false);
     }
     KexiUtils::removeWaitCursor();
 }
@@ -446,7 +468,7 @@ KexiMigrate* ImportTableWizard::prepareImport(Kexi::ObjectStatus& result)
     if (sourceDriverName.isEmpty())
         result.setStatus(i18n("No appropriate migration driver found."),
                             m_migrateManager->possibleProblemsInfoMsg());
-
+  
     
     // Get a source (migration) driver
     KexiMigrate* sourceDriver = 0;
@@ -579,3 +601,13 @@ bool ImportTableWizard::doImport()
     
     return true;
 }
+
+void ImportTableWizard::slotConnPageItemSelected(bool isSelected)
+{
+    setValid(m_srcConnPageItem, isSelected);
+}
+
+void ImportTableWizard::slotTableListWidgetSelectionChanged()
+{
+    setValid(m_tablesPageItem, !m_tableListWidget->selectedItems().isEmpty());
+}
