@@ -59,8 +59,6 @@
 
 #include <kexi_global.h>
 
-//#define MAX_FIELDS 101 //nice prime number
-
 //! used only for BLOBs
 #define DEFAULT_OBJECT_TYPE_VALUE "image"
 
@@ -267,9 +265,9 @@ void KexiTableDesignerView::initData()
 //  d->sets->clear();//default size
 // }
 
-    //add empty space
-// const int columnsCount = d->data->columnsCount();
-    for (int i = tableFieldCount; i < (int)d->sets->size(); i++) {
+    //add empty space, at least 2 times more than number of existing fields
+    uint fullSize = qMax(d->sets->size(), uint(2 * tableFieldCount));
+    for (int i = tableFieldCount; i < fullSize; i++) {
 //  KexiDB::RecordData *item = new KexiDB::RecordData(columnsCount);//3 empty fields
         d->data->append(d->data->createItem());
     }
@@ -398,7 +396,7 @@ KexiTableDesignerView::createPropertySet(int row, const KexiDB::Field& field, bo
                      = new KoProperty::Property("unsigned", QVariant(field.isUnsigned()), i18n("Unsigned Number")));
 
     set->addProperty(prop
-                     = new KoProperty::Property("length", (int)field.length()/*200?*/, i18n("Length")));
+                     = new KoProperty::Property("maxLength", (int)field.maxLength()/*200?*/, i18n("Length")));
 
     set->addProperty(prop
                      = new KoProperty::Property("precision", (int)field.precision()/*200?*/, i18n("Precision")));
@@ -696,8 +694,8 @@ void KexiTableDesignerView::slotBeforeCellChanged(
 
             //update field caption and name
             propertySetForRecord->changeProperty("caption", newValue);
-            propertySetForRecord->changeProperty("name", newValue); // "name" prop. is of custom type Identifier, so this assignment
-            // will automatically convert newValue to an valid identifier
+            propertySetForRecord->changeProperty("name",
+                KexiUtils::string2Identifier(newValue.toString()));
 
             //remember this action containing 2 subactions
             CommandGroup *changeCaptionAndNameCommand = new CommandGroup(
