@@ -115,8 +115,9 @@ void KexiInputTableEdit::init()
         m_lineedit->setAlignment(Qt::AlignRight);
     }
 
-    if (field()->isTextType())
-        m_lineedit->setMaxLength(field()->length());
+    if (field()->type() == KexiDB::Field::Text && field()->maxLength() > 0) {
+        m_lineedit->setMaxLength(field()->maxLength());
+    }
     setViewWidget(m_lineedit);
     m_calculatedCell = false;
 
