@@ -55,7 +55,9 @@ void KisToolText::finishRect(const QRectF &rect)
     if (textFactory) {
         KoShape* shape = textFactory->createDefaultShape(canvas()->shapeController()->resourceManager());
         shape->setSize(r.size());
-        shape->setPosition(r.topLeft());
+        qreal x = r.x() + r.width() / 2;
+        qreal y = r.y() + r.height() / 2;
+        shape->setPosition(QPointF(x,y));
         addShape(shape);
 
         KisCanvas2* kiscanvas = dynamic_cast<KisCanvas2 *>(canvas());
