@@ -37,7 +37,7 @@ public:
     KisSelectionToolHelper(KisCanvas2* canvas, KisNodeSP node, const QString& name);
     virtual ~KisSelectionToolHelper();
 
-    void selectPixelSelection(KisPixelSelectionSP selection, selectionAction action);
+    void selectPixelSelection(KisPixelSelectionSP selection, SelectionAction action);
     void addSelectionShape(KoShape* shape);
 
 private:
