@@ -207,10 +207,12 @@ public:
     virtual EffortCostMap plannedEffortCostPrDay( const QDate &start, const QDate &end, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const;
     virtual EffortCostMap plannedEffortCostPrDay(const Resource *resource, const QDate &start, const QDate &end, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const;
 
+    using Node::plannedEffort;
     /// Returns the total planned effort for this project (or subproject)
     virtual Duration plannedEffort( long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All ) const;
     /// Returns the total planned effort for this project (or subproject) on date
     virtual Duration plannedEffort( const QDate &date, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All  ) const;
+    using Node::plannedEffortTo;
     /// Returns the planned effort up to and including date
     virtual Duration plannedEffortTo( const QDate &date, long id = CURRENTSCHEDULE, EffortCostCalculationType = ECCT_All  ) const;
 
@@ -682,13 +684,6 @@ private:
     QList<Task*> m_softConstraints;
     QList<Task*> m_terminalNodes;
     
-#ifndef NDEBUG
-public:
-    void printDebug( bool children, const QByteArray& indent );
-    void printCalendarDebug( const QByteArray& indent = "" );
-
-	
-#endif
 };
 
 
